==> novelai_python-0.2.7-py3-none-any.whl: novelai_python/_exceptions.py <==
# -*- coding: utf-8 -*-
# @Time    : 2024/1/26 上午10:55
# @Author  : sudoskys
# @File    : _exceptions.py
# @Software: PyCharm
from typing import Any, Optional, Union, Dict


class NovelAiError(Exception):
    """
    NovelAiError is the base exception for all novelai_python errors.
    """
    pass


class InvalidRequestHeader(NovelAiError):
    """
    InvalidRequestHeader is raised when the request header is invalid.
    """
    pass


class APIError(NovelAiError):
    """
    APIError is raised when the API returns an error.
    """
    message: str
    request: Any
    code: Optional[str] = None
    response: Union[Dict[str, Any], str] = None

    def __init__(self, message: str, request: dict, response: Union[dict, str], status_code: str) -> None:
        if not isinstance(response, dict):
            response = {"error": f"data type error, should be dict, but got {type(response)}"}
        if not isinstance(request, dict):
            request = {"error": f"data type error, should be dict, but got {type(request)}"}
        self.request = request
        self.message = message
        self.code = status_code
        self.response = response

    @property
    def __dict__(self):
        return {
            "message": self.message,
            "request": self.request,
            "response": self.response,
            "code": self.code
        }


class ConcurrentGenerationError(APIError):
    """
    ConcurrentGenerationError is raised when the API returns an error.
    """

    def __init__(self, message: str, request: dict, response: Union[dict, str], status_code: str) -> None:
        super().__init__(message, request, response, status_code)


class AuthError(APIError):
    """
    AuthError is raised when the API returns an error.
    """

    def __init__(self, message: str, request: dict, response: Union[dict, str], status_code: str) -> None:
        super().__init__(message, request, response, status_code)

==> novelai_python-0.4.13-py3-none-any.whl: novelai_python/_exceptions.py <==
# -*- coding: utf-8 -*-
# @Time    : 2024/1/26 上午10:55
# @Author  : sudoskys
# @File    : _exceptions.py

from typing import Any, Union, Dict


class NovelAiError(Exception):
    """
    NovelAiError is the base exception for all novelai_python errors.
    """
    message: str

    def __init__(self, message: str) -> None:
        self.message = message

    @property
    def __dict__(self):
        return {
            "message": self.message,
        }


class InvalidRequestHeader(NovelAiError):
    """
    InvalidRequestHeader is raised when the request header is invalid.
    """
    pass


class SessionHttpError(NovelAiError):
    """
    HTTPError is raised when a request to the API fails.
    """
    pass


class APIError(NovelAiError):
    """
    APIError is raised when the API returns an error.
    """
    request: Any
    code: Union[str, None] = None
    response: Union[Dict[str, Any], str] = None

    def __init__(self,
                 message: str,
                 request: Any,
                 response: Union[Dict[str, Any], str],
                 code: Union[str, None]
                 ) -> None:
        super().__init__(message)
        self.request = request
        self.response = response
        self.code = code

    @property
    def __dict__(self):
        parent_dict = super().__dict__
        parent_dict.update({
            "request": self.request,
            "response": self.response,
            "code": self.code
        })
        return parent_dict


class ConcurrentGenerationError(APIError):
    """
    ConcurrentGenerationError is raised when the API returns an error.
    """

    pass


class AuthError(APIError):
    """
    AuthError is raised when the API returns an error.
    """

    pass
